Coverage for tictactoe/wsgi: 0%

# Coverage for tictactoe/wsgi : 0%

## 7 statements 0 run 7 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | """ WSGI config for tictactoe project. It exposes the WSGI callable as a module-level variable named ``application``. For more information on this file, see https://docs.djangoproject.com/en/dev/howto/deployment/wsgi/ """ import os os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tictactoe.settings") from django.core.wsgi import get_wsgi_application application = get_wsgi_application() from django.conf import settings if not settings.DEBUG: assert settings.SECRET_KEY != 'supersecret'